==> blesta-5.10.2.zip: blesta/components/modules/centovacast/language/tr_tr/centovacast.php <==
<?php
/**
 * Centovacast
 *
 * @package blesta
 * @subpackage blesta.language.tr_tr
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Centovacast.service_info.hostname'] = 'Ana bilgisayar adı';
$lang['Centovacast.!error.centovacast_adminpassword.valid'] = 'Şifre en az 5 karakter uzunluğunda olmalıdır.';
$lang['Centovacast.!error.centovacast_hostname.format'] = 'Lütfen geçerli bir ana bilgisayar adı girin, örn. domain.com.';
$lang['Centovacast.!error.module_row.missing'] = 'Dahili bir hata oluştu. Modül satırı kullanılamıyor.';
$lang['Centovacast.!error.api.internal'] = 'Dahili bir hata oluştu veya sunucu isteğe yanıt vermedi.';
$lang['Centovacast.!error.meta[diskquota].valid'] = 'Disk Kotası sayısal bir değer olmalıdır.';
$lang['Centovacast.!error.meta[transferlimit].valid'] = 'Aktarım Sınırı sayısal bir değer olmalıdır.';
$lang['Centovacast.!error.meta[maxbitrate].valid'] = 'Maksimum Bit Hızı sayısal bir değer olmalıdır.';
$lang['Centovacast.!error.meta[maxclients].valid'] = 'Maksimum Müşteri sayısal bir değer olmalıdır.';
$lang['Centovacast.!error.meta[usesource].valid'] = 'Otomatik DJ Yetenekleri geçersiz görünüyor.';
$lang['Centovacast.!error.meta[apptypes].valid'] = 'Otomatik DJ Tipi geçersiz görünüyor.';
$lang['Centovacast.!error.meta[servertype].valid'] = 'Sunucu Türü geçersiz görünüyor.';
$lang['Centovacast.!error.port_valid'] = 'Bağlantı Noktası sayısal bir değer olmalıdır.';
$lang['Centovacast.!error.account_limit_valid'] = 'Hesap Sınırı boş bırakılmalı (sınırsız hesaplar için) veya bir tamsayı değerine ayarlanmalıdır.';
$lang['Centovacast.!error.password_valid_connection'] = 'Sunucuya bağlantı kurulamadı. Lütfen Ana Bilgisayar Adı, Kullanıcı Adı, Bağlantı Noktası ve Parolanın doğru olduğundan emin olmak için kontrol edin.';
$lang['Centovacast.!error.password_valid'] = 'Şifre geçersiz görünüyor.';
$lang['Centovacast.!error.user_name_valid'] = 'Kullanıcı adı geçersiz görünüyor.';
$lang['Centovacast.!error.host_name_valid'] = 'Ana Bilgisayar Adı geçersiz görünüyor.';
$lang['Centovacast.!error.server_name_valid'] = 'Bir Sunucu Etiketi girmelisiniz.';
$lang['Centovacast.service_field.tooltip.port'] = 'Hesap için belirli bir bağlantı noktası ayarlayın, otomatik olarak bir bağlantı noktası seçmek için boş bırakın.';
$lang['Centovacast.service_field.tooltip.ipaddress'] = 'Varsayılan IP adresinin üzerine yaz.';
$lang['Centovacast.package_fields.tooltip.diskquota'] = 'Bu akış için maksimum disk alanını megabayt (MB) cinsinden belirtir. 0 sınırsız anlamına gelir.';
$lang['Centovacast.package_fields.tooltip.transferlimit'] = 'Bu akış için aylık maksimum veri aktarımını megabayt (MB) cinsinden belirtir. 0 sınırsız anlamına gelir.';
$lang['Centovacast.package_fields.tooltip.maxbitrate'] = 'Bu akış için maksimum bit hızını saniye başına kilobit (kbps) cinsinden belirtir.';
$lang['Centovacast.package_fields.tooltip.maxclients'] = 'Akışı aynı anda ayarlayabilecek maksimum dinleyici sayısını belirtir.';
$lang['Centovacast.service_info.option_login'] = 'Giriş';
$lang['Centovacast.service_info.options'] = 'Seçenekler';
$lang['Centovacast.service_info.password'] = 'Şifre';
$lang['Centovacast.service_info.username'] = 'Kullanıcı Adı';
$lang['Centovacast.tab_client_stats.usage_unlimited'] = '(%1$s MB/∞)';
$lang['Centovacast.tab_client_stats.usage'] = '(%1$s MB/%2$s MB)';
$lang['Centovacast.tab_client_stats.disk_title'] = 'Disk Kullanımı';
$lang['Centovacast.tab_client_stats.bandwidth_title'] = 'Bant Genişliği Kullanımı (Aydan Bugüne)';
$lang['Centovacast.tab_client_stats.info.sourcepassword'] = 'Kaynak Şifre';
$lang['Centovacast.tab_client_stats.info.adminpassword'] = 'Şifre';
$lang['Centovacast.tab_client_stats.info.maxbitrate'] = 'Maksimum Bitare (Kbps)';
$lang['Centovacast.tab_client_stats.info.samplerate'] = 'Örnek Hızı (Hz)';
$lang['Centovacast.tab_client_stats.info.maxclients'] = 'Maksimum Müşteri';
$lang['Centovacast.tab_client_stats.info.port'] = 'Liman';
$lang['Centovacast.tab_client_stats.info.ipaddress'] = 'IP Adresi';
$lang['Centovacast.tab_client_stats.info.hostname'] = 'Ana bilgisayar adı';
$lang['Centovacast.tab_client_stats.info.username'] = 'Kullanıcı Adı';
$lang['Centovacast.tab_client_stats.info_heading.value'] = 'Değer';
$lang['Centovacast.tab_client_stats.info_heading.field'] = 'Saha';
$lang['Centovacast.tab_client_stats.info_title'] = 'Bilgi';
$lang['Centovacast.tab_client_actions.field_password_submit'] = 'Şifreyi Güncelle';
$lang['Centovacast.tab_client_actions.field_password'] = 'Şifre';
$lang['Centovacast.tab_client_actions.heading_password'] = 'Şifre Değiştir';
$lang['Centovacast.tab_client_actions.field_radio_title_submit'] = 'Radyo Başlığını Güncelle';
$lang['Centovacast.tab_client_actions.field_radio_title'] = 'Radyo Başlığı';
$lang['Centovacast.tab_client_actions.heading_radio_title'] = 'Radyo Başlığını Değiştir';
$lang['Centovacast.tab_client_actions.field_genre_submit'] = 'Güncelleme Türü';
$lang['Centovacast.tab_client_actions.field_genre'] = 'Tür';
$lang['Centovacast.tab_client_actions.heading_genre'] = 'Tür Değiştir';
$lang['Centovacast.tab_client_actions.action_password'] = 'Şifre Değiştir';
$lang['Centovacast.tab_client_actions.action_start'] = 'Başlangıç';
$lang['Centovacast.tab_client_actions.action_radio_title'] = 'Radyo Başlığını Değiştir';
$lang['Centovacast.tab_client_actions.action_stop'] = 'Dur';
$lang['Centovacast.tab_client_actions.action_genre'] = 'Tür Değiştir';
$lang['Centovacast.tab_client_actions.action_restart'] = 'Yeniden Başlat';
$lang['Centovacast.tab_client_actions.heading_actions'] = 'Eylemler';
$lang['Centovacast.tab_client_actions.status_offline'] = 'Çevrimdışı';
$lang['Centovacast.tab_client_actions.status_online'] = 'Çevrimiçi';
$lang['Centovacast.tab_client_actions.heading_status'] = 'Sunucu Durumu';
$lang['Centovacast.tab_stats.disk_unlimited'] = 'sınırsız';
$lang['Centovacast.tab_stats.disk_value'] = '1$s MB';
$lang['Centovacast.tab_stats.disk_heading.limit'] = 'Limit';
$lang['Centovacast.tab_stats.disk_heading.used'] = 'Kullanılmış';
$lang['Centovacast.tab_stats.disk_title'] = 'Disk';
$lang['Centovacast.tab_stats.bandwidth_unlimited'] = 'sınırsız';
$lang['Centovacast.tab_stats.bandwidth_value'] = '1$s MB';
$lang['Centovacast.tab_stats.bandwidth_heading.limit'] = 'Limit';
$lang['Centovacast.tab_stats.bandwidth_heading.used'] = 'Kullanılmış';
$lang['Centovacast.tab_stats.bandwidth_title'] = 'Bant Genişliği';
$lang['Centovacast.tab_stats.info.sourcepassword'] = 'Kaynak Şifre';
$lang['Centovacast.tab_stats.info.adminpassword'] = 'Şifre';
$lang['Centovacast.tab_stats.info.maxbitrate'] = 'Maksimum Bitare (Kbps)';
$lang['Centovacast.tab_stats.info.samplerate'] = 'Örnek Hızı (Hz)';
$lang['Centovacast.tab_stats.info.maxclients'] = 'Maksimum Müşteri';
$lang['Centovacast.tab_stats.info.port'] = 'Liman';
$lang['Centovacast.tab_stats.info.ipaddress'] = 'IP Adresi';
$lang['Centovacast.tab_stats.info.hostname'] = 'Ana bilgisayar adı';
$lang['Centovacast.tab_stats.info.username'] = 'Kullanıcı Adı';
$lang['Centovacast.tab_stats.info_heading.value'] = 'Değer';
$lang['Centovacast.tab_stats.info_heading.field'] = 'Saha';
$lang['Centovacast.tab_stats.info_title'] = 'Bilgi';
$lang['Centovacast.tab_actions.action_start'] = 'Başlangıç';
$lang['Centovacast.tab_actions.action_stop'] = 'Dur';
$lang['Centovacast.tab_actions.action_restart'] = 'Yeniden Başlat';
$lang['Centovacast.tab_actions.server_title'] = 'Sunucu Eylemleri';
$lang['Centovacast.tab_actions.status_title'] = 'Sunucu Durumu';
$lang['Centovacast.service_field.port'] = 'Liman';
$lang['Centovacast.service_field.ipaddress'] = 'IP Adresi';
$lang['Centovacast.service_field.genre'] = 'Tür';
$lang['Centovacast.service_field.title'] = 'Başlık';
$lang['Centovacast.service_field.password'] = 'Şifre';
$lang['Centovacast.service_field.hostname'] = 'Ana bilgisayar adı';
$lang['Centovacast.package_fields.diskquota'] = 'Disk Kotası';
$lang['Centovacast.package_fields.transferlimit'] = 'Transfer Limiti';
$lang['Centovacast.package_fields.maxbitrate'] = 'Maksimum Bit Hızı';
$lang['Centovacast.package_fields.maxclients'] = 'Maksimum Müşteri';
$lang['Centovacast.package_fields.usesource'] = 'AutoDJ Yetenekleri';
$lang['Centovacast.package_fields.apptypes'] = 'AutoDJ Tipi';
$lang['Centovacast.package_fields.servertype'] = 'Sunucu Tipi';
$lang['Centovacast.row_meta.account_limit'] = 'Hesap Limiti';
$lang['Centovacast.row_meta.use_ssl'] = 'API\'ye bağlanırken SSL kullanın (önerilir)';
$lang['Centovacast.row_meta.port'] = 'Liman';
$lang['Centovacast.row_meta.password'] = 'Şifre';
$lang['Centovacast.row_meta.username'] = 'Kullanıcı Adı';
$lang['Centovacast.row_meta.ipaddress'] = 'IP Adresi';
$lang['Centovacast.row_meta.hostname'] = 'Ana bilgisayar adı';
$lang['Centovacast.row_meta.server_name'] = 'Sunucu Etiketi';
$lang['Centovacast.edit_row.add_btn'] = 'Sunucuyu Düzenle';
$lang['Centovacast.edit_row.notes_title'] = 'Notlar';
$lang['Centovacast.edit_row.basic_title'] = 'Temel Ayarlar';
$lang['Centovacast.edit_row.box_title'] = 'CentovaCast Sunucusunu Düzenleme';
$lang['Centovacast.add_row.add_btn'] = 'Sunucu Ekle';
$lang['Centovacast.add_row.notes_title'] = 'Notlar';
$lang['Centovacast.add_row.basic_title'] = 'Temel Ayarlar';
$lang['Centovacast.add_row.box_title'] = 'CentovaCast Sunucusu Ekleme';
$lang['Centovacast.order_options.roundrobin'] = 'Sunucular Arasında Eşit Olarak Dağıtın';
$lang['Centovacast.order_options.first'] = 'İlk Dolu Olmayan Sunucu';
$lang['Centovacast.manage.module_groups_no_results'] = 'Sunucu grubu yoktur.';
$lang['Centovacast.manage.module_rows_no_results'] = 'Sunucu yok.';
$lang['Centovacast.manage.module_groups.confirm_delete'] = 'Bu sunucu grubunu silmek istediğinizden emin misiniz?';
$lang['Centovacast.manage.module_rows.confirm_delete'] = 'Bu sunucuyu silmek istediğinizden emin misiniz?';
$lang['Centovacast.manage.module_groups.delete'] = 'Silme';
$lang['Centovacast.manage.module_rows.delete'] = 'Silme';
$lang['Centovacast.manage.module_groups.edit'] = 'Düzenle';
$lang['Centovacast.manage.module_rows.edit'] = 'Düzenle';
$lang['Centovacast.manage.module_rows.count'] = '1$s / %2$s';
$lang['Centovacast.manage.module_groups_heading.options'] = 'Seçenekler';
$lang['Centovacast.manage.module_groups_heading.servers'] = 'Sunucu Sayısı';
$lang['Centovacast.manage.module_groups_heading.name'] = 'Grup Adı';
$lang['Centovacast.manage.module_rows_heading.options'] = 'Seçenekler';
$lang['Centovacast.manage.module_rows_heading.accounts'] = 'Hesaplar';
$lang['Centovacast.manage.module_rows_heading.hostname'] = 'Ana bilgisayar adı';
$lang['Centovacast.manage.module_rows_heading.name'] = 'Sunucu Etiketi';
$lang['Centovacast.manage.module_groups_title'] = 'Sunucu Grupları';
$lang['Centovacast.manage.module_rows_title'] = 'Sunucular';
$lang['Centovacast.add_module_group'] = 'Sunucu Grubu Ekleme';
$lang['Centovacast.add_module_row'] = 'Sunucu Ekle';
$lang['Centovacast.tab_client_actions'] = 'Eylemler';
$lang['Centovacast.tab_client_stats'] = 'İstatistikler';
$lang['Centovacast.tab_actions'] = 'Eylemler';
$lang['Centovacast.tab_stats'] = 'İstatistikler';
$lang['Centovacast.module_group'] = 'Sunucu Grubu';
$lang['Centovacast.module_row_plural'] = 'Sunucular';
$lang['Centovacast.module_row'] = 'Sunucu';
$lang['Centovacast.description'] = 'Tek bir istasyonu kolaylıkla yönetin veya binlerce müşterisi olan bir yayın barındırma işini otomatikleştirin. Centova Cast neredeyse her türlü yayın barındırma senaryosunun üstesinden gelebilir!';
$lang['Centovacast.name'] = 'CentovaCast';

==> blesta-5.11.4.zip: blesta/components/modules/centovacast/language/tr_tr/centovacast.php <==
<?php
/**
 * Centovacast
 *
 * @package blesta
 * @subpackage blesta.language.tr_tr
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Centovacast.service_info.hostname'] = 'Ana bilgisayar adı';
$lang['Centovacast.!error.centovacast_adminpassword.valid'] = 'Şifre en az 5 karakter uzunluğunda olmalıdır.';
$lang['Centovacast.!error.centovacast_hostname.format'] = 'Lütfen geçerli bir ana bilgisayar adı girin, örn. domain.com.';
$lang['Centovacast.!error.module_row.missing'] = 'Dahili bir hata oluştu. Modül satırı kullanılamıyor.';
$lang['Centovacast.!error.api.internal'] = 'Dahili bir hata oluştu veya sunucu isteğe yanıt vermedi.';
$lang['Centovacast.!error.meta[diskquota].valid'] = 'Disk Kotası sayısal bir değer olmalıdır.';
$lang['Centovacast.!error.meta[transferlimit].valid'] = 'Aktarım Sınırı sayısal bir değer olmalıdır.';
$lang['Centovacast.!error.meta[maxbitrate].valid'] = 'Maksimum Bit Hızı sayısal bir değer olmalıdır.';
$lang['Centovacast.!error.meta[maxclients].valid'] = 'Maksimum Müşteri sayısal bir değer olmalıdır.';
$lang['Centovacast.!error.meta[usesource].valid'] = 'Otomatik DJ Yetenekleri geçersiz görünüyor.';
$lang['Centovacast.!error.meta[apptypes].valid'] = 'Otomatik DJ Tipi geçersiz görünüyor.';
$lang['Centovacast.!error.meta[servertype].valid'] = 'Sunucu Türü geçersiz görünüyor.';
$lang['Centovacast.!error.port_valid'] = 'Bağlantı Noktası sayısal bir değer olmalıdır.';
$lang['Centovacast.!error.account_limit_valid'] = 'Hesap Sınırı boş bırakılmalı (sınırsız hesaplar için) veya bir tamsayı değerine ayarlanmalıdır.';
$lang['Centovacast.!error.password_valid_connection'] = 'Sunucuya bağlantı kurulamadı. Lütfen Ana Bilgisayar Adı, Kullanıcı Adı, Bağlantı Noktası ve Parolanın doğru olduğundan emin olmak için kontrol edin.';
$lang['Centovacast.!error.password_valid'] = 'Şifre geçersiz görünüyor.';
$lang['Centovacast.!error.user_name_valid'] = 'Kullanıcı adı geçersiz görünüyor.';
$lang['Centovacast.!error.host_name_valid'] = 'Ana Bilgisayar Adı geçersiz görünüyor.';
$lang['Centovacast.!error.server_name_valid'] = 'Bir Sunucu Etiketi girmelisiniz.';
$lang['Centovacast.service_field.tooltip.port'] = 'Hesap için belirli bir bağlantı noktası ayarlayın, otomatik olarak bir bağlantı noktası seçmek için boş bırakın.';
$lang['Centovacast.service_field.tooltip.ipaddress'] = 'Varsayılan IP adresinin üzerine yaz.';
$lang['Centovacast.package_fields.tooltip.diskquota'] = 'Bu akış için maksimum disk alanını megabayt (MB) cinsinden belirtir. 0 sınırsız anlamına gelir.';
$lang['Centovacast.package_fields.tooltip.transferlimit'] = 'Bu akış için aylık maksimum veri aktarımını megabayt (MB) cinsinden belirtir. 0 sınırsız anlamına gelir.';
$lang['Centovacast.package_fields.tooltip.maxbitrate'] = 'Bu akış için maksimum bit hızını saniye başına kilobit (kbps) cinsinden belirtir.';
$lang['Centovacast.package_fields.tooltip.maxclients'] = 'Akışı aynı anda ayarlayabilecek maksimum dinleyici sayısını belirtir.';
$lang['Centovacast.service_info.option_login'] = 'Giriş';
$lang['Centovacast.service_info.options'] = 'Seçenekler';
$lang['Centovacast.service_info.password'] = 'Şifre';
$lang['Centovacast.service_info.username'] = 'Kullanıcı Adı';
$lang['Centovacast.tab_client_stats.usage_unlimited'] = '(%1$s MB/∞)';
$lang['Centovacast.tab_client_stats.usage'] = '(%1$s MB/%2$s MB)';
$lang['Centovacast.tab_client_stats.disk_title'] = 'Disk Kullanımı';
$lang['Centovacast.tab_client_stats.bandwidth_title'] = 'Bant Genişliği Kullanımı (Aydan Bugüne)';
$lang['Centovacast.tab_client_stats.info.sourcepassword'] = 'Kaynak Şifre';
$lang['Centovacast.tab_client_stats.info.adminpassword'] = 'Şifre';
$lang['Centovacast.tab_client_stats.info.maxbitrate'] = 'Maksimum Bitare (Kbps)';
$lang['Centovacast.tab_client_stats.info.samplerate'] = 'Örnek Hızı (Hz)';
$lang['Centovacast.tab_client_stats.info.maxclients'] = 'Maksimum Müşteri';
$lang['Centovacast.tab_client_stats.info.port'] = 'Liman';
$lang['Centovacast.tab_client_stats.info.ipaddress'] = 'IP Adresi';
$lang['Centovacast.tab_client_stats.info.hostname'] = 'Ana bilgisayar adı';
$lang['Centovacast.tab_client_stats.info.username'] = 'Kullanıcı Adı';
$lang['Centovacast.tab_client_stats.info_heading.value'] = 'Değer';
$lang['Centovacast.tab_client_stats.info_heading.field'] = 'Saha';
$lang['Centovacast.tab_client_stats.info_title'] = 'Bilgi';
$lang['Centovacast.tab_client_actions.field_password_submit'] = 'Şifreyi Güncelle';
$lang['Centovacast.tab_client_actions.field_password'] = 'Şifre';
$lang['Centovacast.tab_client_actions.heading_password'] = 'Şifre Değiştir';
$lang['Centovacast.tab_client_actions.field_radio_title_submit'] = 'Radyo Başlığını Güncelle';
$lang['Centovacast.tab_client_actions.field_radio_title'] = 'Radyo Başlığı';
$lang['Centovacast.tab_client_actions.heading_radio_title'] = 'Radyo Başlığını Değiştir';
$lang['Centovacast.tab_client_actions.field_genre_submit'] = 'Güncelleme Türü';
$lang['Centovacast.tab_client_actions.field_genre'] = 'Tür';
$lang['Centovacast.tab_client_actions.heading_genre'] = 'Tür Değiştir';
$lang['Centovacast.tab_client_actions.action_password'] = 'Şifre Değiştir';
$lang['Centovacast.tab_client_actions.action_start'] = 'Başlangıç';
$lang['Centovacast.tab_client_actions.action_radio_title'] = 'Radyo Başlığını Değiştir';
$lang['Centovacast.tab_client_actions.action_stop'] = 'Dur';
$lang['Centovacast.tab_client_actions.action_genre'] = 'Tür Değiştir';
$lang['Centovacast.tab_client_actions.action_restart'] = 'Yeniden Başlat';
$lang['Centovacast.tab_client_actions.heading_actions'] = 'Eylemler';
$lang['Centovacast.tab_client_actions.status_offline'] = 'Çevrimdışı';
$lang['Centovacast.tab_client_actions.status_online'] = 'Çevrimiçi';
$lang['Centovacast.tab_client_actions.heading_status'] = 'Sunucu Durumu';
$lang['Centovacast.tab_stats.disk_unlimited'] = 'sınırsız';
$lang['Centovacast.tab_stats.disk_heading.limit'] = 'Limit';
$lang['Centovacast.tab_stats.disk_heading.used'] = 'Kullanılmış';
$lang['Centovacast.tab_stats.disk_title'] = 'Disk';
$lang['Centovacast.tab_stats.bandwidth_unlimited'] = 'sınırsız';
$lang['Centovacast.tab_stats.bandwidth_heading.limit'] = 'Limit';
$lang['Centovacast.tab_stats.bandwidth_heading.used'] = 'Kullanılmış';
$lang['Centovacast.tab_stats.bandwidth_title'] = 'Bant Genişliği';
$lang['Centovacast.tab_stats.info.sourcepassword'] = 'Kaynak Şifre';
$lang['Centovacast.tab_stats.info.adminpassword'] = 'Şifre';
$lang['Centovacast.tab_stats.info.maxbitrate'] = 'Maksimum Bitare (Kbps)';
$lang['Centovacast.tab_stats.info.samplerate'] = 'Örnek Hızı (Hz)';
$lang['Centovacast.tab_stats.info.maxclients'] = 'Maksimum Müşteri';
$lang['Centovacast.tab_stats.info.port'] = 'Liman';
$lang['Centovacast.tab_stats.info.ipaddress'] = 'IP Adresi';
$lang['Centovacast.tab_stats.info.hostname'] = 'Ana bilgisayar adı';
$lang['Centovacast.tab_stats.info.username'] = 'Kullanıcı Adı';
$lang['Centovacast.tab_stats.info_heading.value'] = 'Değer';
$lang['Centovacast.tab_stats.info_heading.field'] = 'Saha';
$lang['Centovacast.tab_stats.info_title'] = 'Bilgi';
$lang['Centovacast.tab_actions.action_start'] = 'Başlangıç';
$lang['Centovacast.tab_actions.action_stop'] = 'Dur';
$lang['Centovacast.tab_actions.action_restart'] = 'Yeniden Başlat';
$lang['Centovacast.tab_actions.server_title'] = 'Sunucu Eylemleri';
$lang['Centovacast.tab_actions.status_title'] = 'Sunucu Durumu';
$lang['Centovacast.service_field.port'] = 'Liman';
$lang['Centovacast.service_field.ipaddress'] = 'IP Adresi';
$lang['Centovacast.service_field.genre'] = 'Tür';
$lang['Centovacast.service_field.title'] = 'Başlık';
$lang['Centovacast.service_field.password'] = 'Şifre';
$lang['Centovacast.service_field.hostname'] = 'Ana bilgisayar adı';
$lang['Centovacast.package_fields.diskquota'] = 'Disk Kotası';
$lang['Centovacast.package_fields.transferlimit'] = 'Transfer Limiti';
$lang['Centovacast.package_fields.maxbitrate'] = 'Maksimum Bit Hızı';
$lang['Centovacast.package_fields.maxclients'] = 'Maksimum Müşteri';
$lang['Centovacast.package_fields.usesource'] = 'AutoDJ Yetenekleri';
$lang['Centovacast.package_fields.apptypes'] = 'AutoDJ Tipi';
$lang['Centovacast.package_fields.servertype'] = 'Sunucu Tipi';
$lang['Centovacast.row_meta.account_limit'] = 'Hesap Limiti';
$lang['Centovacast.row_meta.use_ssl'] = 'API\'ye bağlanırken SSL kullanın (önerilir)';
$lang['Centovacast.row_meta.port'] = 'Liman';
$lang['Centovacast.row_meta.password'] = 'Şifre';
$lang['Centovacast.row_meta.username'] = 'Kullanıcı Adı';
$lang['Centovacast.row_meta.ipaddress'] = 'IP Adresi';
$lang['Centovacast.row_meta.hostname'] = 'Ana bilgisayar adı';
$lang['Centovacast.row_meta.server_name'] = 'Sunucu Etiketi';
$lang['Centovacast.edit_row.add_btn'] = 'Sunucuyu Düzenle';
$lang['Centovacast.edit_row.notes_title'] = 'Notlar';
$lang['Centovacast.edit_row.basic_title'] = 'Temel Ayarlar';
$lang['Centovacast.edit_row.box_title'] = 'CentovaCast Sunucusunu Düzenleme';
$lang['Centovacast.add_row.add_btn'] = 'Sunucu Ekle';
$lang['Centovacast.add_row.notes_title'] = 'Notlar';
$lang['Centovacast.add_row.basic_title'] = 'Temel Ayarlar';
$lang['Centovacast.add_row.box_title'] = 'CentovaCast Sunucusu Ekleme';
$lang['Centovacast.order_options.roundrobin'] = 'Sunucular Arasında Eşit Olarak Dağıtın';
$lang['Centovacast.order_options.first'] = 'İlk Dolu Olmayan Sunucu';
$lang['Centovacast.manage.module_groups_no_results'] = 'Sunucu grubu yoktur.';
$lang['Centovacast.manage.module_rows_no_results'] = 'Sunucu yok.';
$lang['Centovacast.manage.module_groups.confirm_delete'] = 'Bu sunucu grubunu silmek istediğinizden emin misiniz?';
$lang['Centovacast.manage.module_rows.confirm_delete'] = 'Bu sunucuyu silmek istediğinizden emin misiniz?';
$lang['Centovacast.manage.module_groups.delete'] = 'Silme';
$lang['Centovacast.manage.module_rows.delete'] = 'Silme';
$lang['Centovacast.manage.module_groups.edit'] = 'Düzenle';
$lang['Centovacast.manage.module_rows.edit'] = 'Düzenle';
$lang['Centovacast.manage.module_groups_heading.options'] = 'Seçenekler';
$lang['Centovacast.manage.module_groups_heading.servers'] = 'Sunucu Sayısı';
$lang['Centovacast.manage.module_groups_heading.name'] = 'Grup Adı';
$lang['Centovacast.manage.module_rows_heading.options'] = 'Seçenekler';
$lang['Centovacast.manage.module_rows_heading.accounts'] = 'Hesaplar';
$lang['Centovacast.manage.module_rows_heading.hostname'] = 'Ana bilgisayar adı';
$lang['Centovacast.manage.module_rows_heading.name'] = 'Sunucu Etiketi';
$lang['Centovacast.manage.module_groups_title'] = 'Sunucu Grupları';
$lang['Centovacast.manage.module_rows_title'] = 'Sunucular';
$lang['Centovacast.add_module_group'] = 'Sunucu Grubu Ekleme';
$lang['Centovacast.add_module_row'] = 'Sunucu Ekle';
$lang['Centovacast.tab_client_actions'] = 'Eylemler';
$lang['Centovacast.tab_client_stats'] = 'İstatistikler';
$lang['Centovacast.tab_actions'] = 'Eylemler';
$lang['Centovacast.tab_stats'] = 'İstatistikler';
$lang['Centovacast.module_group'] = 'Sunucu Grubu';
$lang['Centovacast.module_row_plural'] = 'Sunucular';
$lang['Centovacast.module_row'] = 'Sunucu';
$lang['Centovacast.description'] = 'Tek bir istasyonu kolaylıkla yönetin veya binlerce müşterisi olan bir yayın barındırma işini otomatikleştirin. Centova Cast neredeyse her türlü yayın barındırma senaryosunun üstesinden gelebilir!';
$lang['Centovacast.name'] = 'CentovaCast';
$lang['Centovacast.tab_stats.disk_value'] = '%1$s MB';
$lang['Centovacast.tab_stats.bandwidth_value'] = '%1$s MB';
$lang['Centovacast.manage.module_rows.count'] = '%1$s / %2$s';
